==> Paws-0.35.tar.gz: Paws-0.35/lib/Paws/Glue/MappingEntry.pm <==
package Paws::Glue::MappingEntry;
  use Moose;
  has SourcePath => (is => 'ro', isa => 'Str');
  has SourceTable => (is => 'ro', isa => 'Str');
  has SourceType => (is => 'ro', isa => 'Str');
  has TargetPath => (is => 'ro', isa => 'Str');
  has TargetTable => (is => 'ro', isa => 'Str');
  has TargetType => (is => 'ro', isa => 'Str');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Glue::MappingEntry

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::Glue::MappingEntry object:

  $service_obj->Method(Att1 => { SourcePath => $value, ..., TargetType => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::Glue::MappingEntry object:

  $result = $service_obj->Method(...);
  $result->Att1->SourcePath

=head1 DESCRIPTION

Defines a mapping.

=head1 ATTRIBUTES


=head2 SourcePath => Str

  The source path.


=head2 SourceTable => Str

  The name of the source table.


=head2 SourceType => Str

  The source type.


=head2 TargetPath => Str

  The target path.


=head2 TargetTable => Str

  The target table.


=head2 TargetType => Str

  The target type.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::Glue>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.38.tar.gz: Paws-0.38/lib/Paws/Glue/MappingEntry.pm <==
package Paws::Glue::MappingEntry;
  use Moose;
  has SourcePath => (is => 'ro', isa => 'Str');
  has SourceTable => (is => 'ro', isa => 'Str');
  has SourceType => (is => 'ro', isa => 'Str');
  has TargetPath => (is => 'ro', isa => 'Str');
  has TargetTable => (is => 'ro', isa => 'Str');
  has TargetType => (is => 'ro', isa => 'Str');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Glue::MappingEntry

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::Glue::MappingEntry object:

  $service_obj->Method(Att1 => { SourcePath => $value, ..., TargetType => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::Glue::MappingEntry object:

  $result = $service_obj->Method(...);
  $result->Att1->SourcePath

=head1 DESCRIPTION

Defines a mapping.

=head1 ATTRIBUTES


=head2 SourcePath => Str

  The source path.


=head2 SourceTable => Str

  The name of the source table.


=head2 SourceType => Str

  The source type.


=head2 TargetPath => Str

  The target path.


=head2 TargetTable => Str

  The target table.


=head2 TargetType => Str

  The target type.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::Glue>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
